@@ -3,6 +3,7 @@ package kubernetes
 import (
 	"context"
 	"fmt"
+	"os"
 
 	"github.com/spf13/cobra"
 	fly "github.com/superfly/fly-go"
@@ -36,6 +37,10 @@ func create() (cmd *cobra.Command) {
 		},
 		flag.Org(),
 		flag.Region(),
+		flag.String{
+			Name:        "output",
+			Description: "The output path to save the kubeconfig file",
+		},
 	)
 	return cmd
 }
@@ -66,8 +71,22 @@ func runK8sCreate(ctx context.Context) (err error) {
 		return err
 	}
 
-	metadata := resp.AddOn.Metadata.(map[string]interface{})
+	outFilename := flag.GetString(ctx, "output")
+	if outFilename == "" {
+		outFilename = fmt.Sprintf("%s.kubeconfig.yml", resp.AddOn.Name)
+	}
+	f, err := os.Create(outFilename)
+	if err != nil {
+		return err
+	}
+	defer f.Close()
 
-	fmt.Fprintf(io.Out, "Use the following kubeconfig to connect to your cluster:\n\n%s", metadata["kubeconfig"])
+	metadata := resp.AddOn.Metadata.(map[string]interface{})
+	kubeconfig := metadata["kubeconfig"].(string)
+	if _, err := f.Write([]byte(kubeconfig)); err != nil {
+		return fmt.Errorf("failed to write kubeconfig to file %s, error: %w", outFilename, err)
+	}
+
+	fmt.Fprintf(io.Out, "Wrote kubeconfig to file %s. Use it to connect to your cluster", outFilename)
 	return
 }
