@@ -7,15 +7,16 @@ import (
 	"strconv"
 	"strings"
 
+	"github.com/samber/lo"
 	"github.com/spf13/cobra"
-	"github.com/superfly/flyctl/api"
-	"github.com/superfly/flyctl/client"
-	"github.com/superfly/flyctl/flaps"
+	fly "github.com/superfly/fly-go"
+	"github.com/superfly/fly-go/flaps"
 	"github.com/superfly/flyctl/internal/appconfig"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/flag"
 	"github.com/superfly/flyctl/internal/flag/completion"
-	"github.com/superfly/flyctl/iostreams"
+	"github.com/superfly/flyctl/internal/flapsutil"
+	"golang.org/x/exp/maps"
 )
 
 func newScaleCount() *cobra.Command {
@@ -46,7 +47,9 @@ For pricing, see https://fly.io/docs/about/pricing/`
 
 func runScaleCount(ctx context.Context) error {
 	appName := appconfig.NameFromContext(ctx)
-	flapsClient, err := flaps.NewFromAppName(ctx, appName)
+	flapsClient, err := flapsutil.NewClientWithOptions(ctx, flaps.NewClientOpts{
+		AppName: appName,
+	})
 	if err != nil {
 		return err
 	}
@@ -63,14 +66,7 @@ func runScaleCount(ctx context.Context) error {
 	groupName := flag.GetProcessGroup(ctx)
 
 	if groupName == "" {
-		groupName = api.MachineProcessGroupApp
-		if !slices.Contains(processNames, groupName) {
-			return fmt.Errorf("--process-group flag is required when no group named 'app' is defined")
-		}
-	}
-
-	if !slices.Contains(processNames, groupName) {
-		return fmt.Errorf("process group '%s' not found", groupName)
+		groupName = fly.MachineProcessGroupApp
 	}
 
 	groups, err := parseGroupCounts(args, groupName)
@@ -78,16 +74,22 @@ func runScaleCount(ctx context.Context) error {
 		return err
 	}
 
+	unknownNames := lo.Filter(maps.Keys(groups), func(x string, _ int) bool {
+		return !slices.Contains(processNames, x)
+	})
+	if len(unknownNames) > 0 {
+		return fmt.Errorf(
+			"Attempting to scale unknown process groups %v but valid names are %v.\n"+
+				" Use `fly scale count COUNT --process-group=NAME` \n"+
+				" or multi group syntax `fly scale count NAME1=COUNT1 NAME2=COUNT2 ...`",
+			unknownNames,
+			processNames,
+		)
+	}
+
 	maxPerRegion := flag.GetInt(ctx, "max-per-region")
 
-	isV2, err := command.IsMachinesPlatform(ctx, appName)
-	if err != nil {
-		return err
-	}
-	if isV2 {
-		return runMachinesScaleCount(ctx, appName, appConfig, groups, maxPerRegion)
-	}
-	return runNomadScaleCount(ctx, appName, groups, maxPerRegion)
+	return runMachinesScaleCount(ctx, appName, appConfig, groups, maxPerRegion)
 }
 
 func parseGroupCounts(args []string, defaultGroupName string) (map[string]int, error) {
@@ -119,28 +121,3 @@ func parseGroupCounts(args []string, defaultGroupName string) (map[string]int, e
 
 	return groups, nil
 }
-
-func runNomadScaleCount(ctx context.Context, appName string, groups map[string]int, maxPerRegion int) error {
-	io := iostreams.FromContext(ctx)
-	apiClient := client.FromContext(ctx).API()
-
-	var maxPerRegionPtr *int
-	if maxPerRegion >= 0 {
-		maxPerRegionPtr = &maxPerRegion
-	}
-
-	counts, warnings, err := apiClient.SetAppVMCount(ctx, appName, groups, maxPerRegionPtr)
-	if err != nil {
-		return err
-	}
-
-	if len(warnings) > 0 {
-		for _, warning := range warnings {
-			fmt.Fprintln(io.Out, "Warning:", warning)
-		}
-		fmt.Fprintln(io.Out)
-	}
-
-	fmt.Fprintf(io.Out, "Count changed to %s\n", countMessage(counts))
-	return nil
-}
